@@ -508,7 +508,12 @@ class DeepROC(FullROC):
 
         showInterimPlot = False
         if forFolds:
-            fig, ax = self.plot_folds(plotTitle, saveFileName=saveFileName, showPlot=showInterimPlot)
+            if self.nextfold > 10:
+                # then do not show the legend
+                fig, ax = self.plot_folds(plotTitle, saveFileName=saveFileName, showPlot=showInterimPlot,
+                                          showLegend=False)
+            else:
+                fig, ax = self.plot_folds(plotTitle, saveFileName=saveFileName, showPlot=showInterimPlot)
         else:
             fig, ax = self.plot(plotTitle, showThresholds, showOptimalROCpoints, costs, saveFileName,
                                 numShowThresh, showInterimPlot, labelThresh, full_fpr_tpr)
@@ -589,6 +594,11 @@ class DeepROC(FullROC):
             plt.show()
         # endif
 
+        if saveFileName is not None:
+            saveFileName = saveFileName[0:-4] + f'_{groupIndex}.png'
+            fig.savefig(saveFileName)
+        #endif
+
         # modeShort = mode[:-3]  # training -> train, testing -> test
         # fig.savefig(f'output/ROC_{modeShort}_{testNum}-{index}.png')
 
